==> py_code_helpers-1.0.6.tar.gz: py_code_helpers-1.0.6/src/py_code_helpers/log_helper/helper.py <==
import logging
import os



#: lname (str): default root log name, based on LOG_HELPER_NAME environment variable.
LNAME = os.getenv('LOG_HELPER.NAME', 'log_helper')

#: lfile (str): default root log file, based on LOG_HELPER_FILE environment variable.
LFILE = os.getenv('LOG_HELPER.FILE', '/dev/null')

# root logger
fh = logging.FileHandler(LFILE)
ch = logging.StreamHandler()
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
fh.setFormatter(formatter)
ch.setFormatter(formatter)

def log(log_name=None, log_file=None):
    """Decorator/Wrapper for injecting the logger object as a parameter
    of the decorated method.

    Args:
       log_name (str):  Logger name. Being LOG_HELPER_NAME.log_name the result.

       log_file (str):  Logger file for writing logs to.

    Returns:
       object.  The decorated function

    Raises:
       Custom Exception

    Usage:
    ::
        import py_code_helpers.log_helper.helper as helper

        class TheClass:
            @helper.log(log_name='TestClass', log_file='/dev/null')
            def __init__(self, log):
                self.logger = log

            # and use it like:
            self.logger.info('testing log')
    """
    def decorate(function):
        def wrapper(*args, **kwargs):
            logname = LNAME + '.' + log_name
            logger = logging.getLogger(logname)
            for handler in logger.handlers:
                # add the handlers to the logger
                # makes sure no duplicate handlers are added
                if not isinstance(handler, logging.FileHandler) and not isinstance(handler, logging.StreamHandler):
                    logger.addHandler(ch)
                    if log_file:
                        nfh = logging.FileHandler(log_file)
                        nfh.setFormatter(formatter)
                        logger.addHandler(nfh)
            function(log=logger, *args, **kwargs)
        return wrapper
    return decorate

==> py_code_helpers-1.0.7.tar.gz: py_code_helpers-1.0.7/src/py_code_helpers/log_helper/helper.py <==
import logging
import os



#: lname (str): default root log name, based on LOG_HELPER_NAME environment variable.
LNAME = os.getenv('LOG_HELPER.NAME', 'log_helper')

#: lfile (str): default root log file, based on LOG_HELPER_FILE environment variable.
LFILE = os.getenv('LOG_HELPER.FILE', '/dev/null')

# root logger
fh = logging.FileHandler(LFILE)
ch = logging.StreamHandler()
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
fh.setFormatter(formatter)
ch.setFormatter(formatter)

def log(log_name=None, log_file=None):
    """Decorator/Wrapper for injecting the logger object as a parameter
    of the decorated method.

    Args:
       log_name (str):  Logger name. Being LOG_HELPER_NAME.log_name the result.

       log_file (str):  Logger file for writing logs to.

    Returns:
       object.  The decorated function

    Raises:
       Custom Exception

    Usage:
    ::
        import py_code_helpers.log_helper.helper as helper

        class TheClass:
            @helper.log(log_name='TestClass', log_file='/dev/null')
            def __init__(self, log):
                self.logger = log

            # and use it like:
            self.logger.info('testing log')
    """
    def decorate(function):
        def wrapper(*args, **kwargs):
            logname = LNAME + '.' + log_name
            logger = logging.getLogger(logname)
            for handler in logger.handlers:
                # add the handlers to the logger
                # makes sure no duplicate handlers are added
                if isinstance(handler, logging.StreamHandler):
                    logger.removeHandler(handler)
            logger.addHandler(ch)
            if log_file:
                nfh = logging.FileHandler(log_file)
                nfh.setFormatter(formatter)
                logger.addHandler(nfh)
            function(log=logger, *args, **kwargs)
        return wrapper
    return decorate
